==> haskell-murmur-hash-0.1.0.9-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-murmur-hash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 murmur-hash
version:              0.1.0.9
visibility:           public
id:                   murmur-hash-0.1.0.9-IfHSvf3EOxGJYqUxfP4Lt0
key:                  murmur-hash-0.1.0.9-IfHSvf3EOxGJYqUxfP4Lt0
license:              BSD-3-Clause
maintainer:           Thomas Schilling <nominolo@googlemail.com>
author:               Thomas Schilling
stability:            provisional
homepage:             http://github.com/nominolo/murmur-hash
synopsis:             MurmurHash2 implementation for Haskell.
description:
    Implements MurmurHash2, a good, fast, general-purpose,
    non-cryptographic hashing function.  See
    <http://murmurhash.googlepages.com/> for details.

    This implementation is pure Haskell, so it might be a bit slower
    than a C FFI binding.

category:             Data, Digest
abi:                  5b9eb14c7c5724194c8d6e85332f2f5f
exposed:              True
exposed-modules:      Data.Digest.Murmur32 Data.Digest.Murmur64
import-dirs:          /usr/lib/ghc-8.10.2/site-local/murmur-hash-0.1.0.9
library-dirs:         /usr/lib/ghc-8.10.2/site-local/murmur-hash-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/murmur-hash-0.1.0.9
hs-libraries:         HSmurmur-hash-0.1.0.9-IfHSvf3EOxGJYqUxfP4Lt0
depends:              base-4.14.1.0 bytestring-0.10.10.0
haddock-interfaces:   /usr/share/doc/haskell-murmur-hash/html/murmur-hash.haddock
haddock-html:         /usr/share/doc/haskell-murmur-hash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-murmur-hash-0.1.0.9-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-murmur-hash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 murmur-hash
version:              0.1.0.9
visibility:           public
id:                   murmur-hash-0.1.0.9-GMMq0T3o2RfCFsSNchOE77
key:                  murmur-hash-0.1.0.9-GMMq0T3o2RfCFsSNchOE77
license:              BSD-3-Clause
maintainer:           Thomas Schilling <nominolo@googlemail.com>
author:               Thomas Schilling
stability:            provisional
homepage:             http://github.com/nominolo/murmur-hash
synopsis:             MurmurHash2 implementation for Haskell.
description:
    Implements MurmurHash2, a good, fast, general-purpose,
    non-cryptographic hashing function.  See
    <http://murmurhash.googlepages.com/> for details.

    This implementation is pure Haskell, so it might be a bit slower
    than a C FFI binding.

category:             Data, Digest
abi:                  a377b8c34e6452c8a1cd0b6c8990cb5e
exposed:              True
exposed-modules:      Data.Digest.Murmur32 Data.Digest.Murmur64
import-dirs:          /usr/lib/ghc-8.10.4/site-local/murmur-hash-0.1.0.9
library-dirs:         /usr/lib/ghc-8.10.4/site-local/murmur-hash-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/murmur-hash-0.1.0.9
hs-libraries:         HSmurmur-hash-0.1.0.9-GMMq0T3o2RfCFsSNchOE77
depends:              base-4.14.1.0 bytestring-0.10.12.0
haddock-interfaces:   /usr/share/doc/haskell-murmur-hash/html/murmur-hash.haddock
haddock-html:         /usr/share/doc/haskell-murmur-hash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
